@@ -3,7 +3,10 @@ import unittest
 from django import http
 from django import forms
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.auth.models import User, Group, Permission
+from django.contrib.auth.models import Group, Permission
+
+from django.contrib.auth import get_user_model
+User = get_user_model()
 
 import autocomplete_light
 
@@ -44,9 +47,9 @@ class AutocompleteTestCase(unittest.TestCase):
         self.jazzmen.save()
         self.emos.save()
 
-
     def assert_choices_equal(self, result, test):
-        self.assertEqual(result, test['expected'])
+        self.assertEqual(result, test['expected'],
+                'Unexpected result %s\nTest: %s' % (result, test))
 
     def test_choices_for_request(self):
         if not hasattr(self, 'get_choices_for_request_tests'):
