@@ -1,7 +1,8 @@
 import unittest
 
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.db import models
+User = get_user_model()
 
 import autocomplete_light
 
@@ -87,3 +88,10 @@ class RegistryTestCase(unittest.TestCase):
     def test_register_generic_with_custom_name(self):
         self.registry.register(Generic, name='foo')
         self.assertTrue('foo' in self.registry.keys())
+
+    def test_raise_AutocompleteNotRegistered(self):
+        try:
+            self.registry['NotRegistered']
+            self.fail('Should raise AutocompleteNotRegistered')
+        except autocomplete_light.AutocompleteNotRegistered:
+            pass
